xquery version "3.1";

module namespace kmgnav-utils="http://bdn-edition.de/ns/kmgnav-utils";
declare namespace bdn="http://www.bdn-edition.de/ns/1.0";
declare namespace tei="http://www.tei-c.org/ns/1.0";
(:declare namespace templates="http://exist-db.org/xquery/templates";:)
declare namespace tgmd="http://textgrid.info/namespaces/metadata/core/2010";
declare namespace xhtml="http://www.w3.org/1999/xhtml";


import module namespace templates="http://exist-db.org/xquery/templates";
import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";


import module namespace console="http://exist-db.org/xquery/console";

(: 
 Main template function for creating the second grey edition specific navigation bar
:)
declare function kmgnav-utils:nav-injection($node as node(), $model as map(*))
as element(nav)
{
  <nav id="edition-menu" class="nav navbar navbar-default">
      {kmgnav-utils:make-xs-sm-navbar($model)}

      <div class="row hidden-xs hidden-sm">
          <div class="dropdown-container">
              <span class="dropdown edition-menu-button">
                  <a class="btn dropdown-toggle edition-menu-link" href="#" role="button" id="view-button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                      <i class="far fa-eye"></i>
                      Ansichten <i class="fas fa-caret-down"></i>
                  </a>

                  <div class="dropdown-menu edition-menu-dropdown" aria-labelledby="dropdownMenuLink">
                      {templates:process(<span data-template="kmgnav-utils:make-views-content" />, $model)}
                  </div>
              </span>

          </div>
          <div class="title-display" aria-labelledby="titleDisplay">
              {templates:process(<span data-template="kmgnav-utils:get-title" />, $model)}
          </div>
      </div>
  </nav>
};

(:~
 : Creates the edition specific menu for mobile application, 
 : e.g. if the screen is too small the menu changes to a three
 : lined fold out menu
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @author Johannes Biermann
Creates 
:)
declare function kmgnav-utils:make-xs-sm-navbar($model as map(*))
as element(div)
{
   <div class="container-fluid visible-xs visible-sm">
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class="navbar-header">
      <button type="button" class="navbar-toggle collapsed" data-toggle="collapse"
      data-target="#navbar-edition-burger" aria-expanded="false">
        <span class="sr-only">Toggle navigation</span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
        <span class="visible-xs visible-sm navbar-edition-label navbar-brand">
            {templates:process(<span data-template="kmgnav-utils:get-title" />, $model)}

        </span>
    </div>

    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class="collapse navbar-collapse" id="navbar-edition-burger">
      <ul class="nav navbar-nav">
        <li class="dropdown">
          <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button"
          aria-haspopup="true" aria-expanded="false">Ansichten <span class="caret"></span></a>
          <ul id="navbar-edition-burger-views" class="dropdown-menu">
            {templates:process(<span data-template="kmgnav-utils:make-views-content" />, $model)}
          </ul>
        </li>

      </ul>
    </div>
  </div>
};

(:~
 : Creates the content for the views panel of the text
 : (e.g. diplomatic view, synoptic view)
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @author Johannes Biermann
 : @version 1.0
 : @param $model The model of the current page
 : @return element(span) Containing the body content
 :)
declare function kmgnav-utils:make-views-content($node as node()*, $model as map(*))
as element(div)*
{
  let $filename := request:get-parameter("file","")
  let $file := doc($config:sade-data || "kmg/" || $filename || ".xml")
  
  let $edts-tmp := string-join($file//tei:witness/@xml:id/string(), " ")
  
  let $editions := distinct-values(tokenize($edts-tmp, "[#\s]+"))
  
  (: makes iterating easier :)
  let $desc := string-join($file//tei:witness/tei:desc, "_")

  let $baseText := $file//tei:witness[1]/@xml:id/string()
  

  return
      <div class="views">
        <!--<div class="dropdown-divider"></div>-->
        {
                  (:<a class="dropdown-item" href="{kmgnav-utils:make-url($filename, "digital")}">
                    Interaktive textkritische Ansicht mit {$baseText} als Leittext
                  </a>,
                  <div class="dropdown-divider"></div>,
                  <a class="dropdown-item" href="{kmgnav-utils:make-url($filename, "app")}">
                    Textkritische Ansicht mit {$baseText} als Leittext
                  </a>,
                  
                  <div class="dropdown-divider"></div>,
                  :)
                <span>
                    {
                    for $edition at $countEdt in $editions
                        for $date at $countDate in tokenize($desc, '_')
                            where $edition != "" and $countEdt = $countDate
                            return
                                if (kmgnav-utils:isViewActive($edition))
                                then
                                    <a class="dropdown-item" href="{kmgnav-utils:make-url($filename, $edition)}">
                                    <strong>Auflage {$edition} ({$date})</strong>
                                    </a>
                                else
                                    <a class="dropdown-item" href="{kmgnav-utils:make-url($filename, $edition)}">
                                    Auflage {$edition} ({$date})
                                    </a>  

                    }
                </span>
        }
        <!--<div class="dropdown-divider"></div>-->
        <!--<a class="dropdown-item" href="{kmgnav-utils:make-url($filename, "code")}">XML/TEI</a>-->
        

      </div>
};


(:~
 : Creates links to kmg.html with all necessary information,
 : i.e. file name and edition view.
 :
 : @author Hannes Riebl
 : @author Michelle Weidling
 : @author Johannes Biermann
 : @version 1.0
 : @param $filename The current file
 : @param $edition The current edition view
 : @param $foreword true() if we want to set a link to the editorial foreword
 : @return The link as xs:string
 :)
declare function kmgnav-utils:make-url($filename as xs:string, $edition as xs:string) as xs:string*
{
        let $url :=
            $config:app-root || "/kmg.html?"
            => substring-after("sade")
        return
            "kmg.html?&#38;file=" || $filename || "&#38;edition=" || $edition
};

(:~
 : Checks if the current view (request parameter edition) matches a certain view
 : can be used to highlight the current view in the navigation as active
 :
 : @author Johannes Biermann
 : @version 1.0
 : @param edition The edition/view to display
 : @return true false depending on if the edition matches the current request paramater
 :)
declare function kmgnav-utils:isViewActive($edition as xs:string) as xs:boolean 
{
     let $activeEdition := request:get-parameter("edition","")
     let $isActive :=
         if (compare($activeEdition, $edition) = 0)
         then
            true()
         else
            false()
            
     return $isActive
};

(:~
 : Creates a span that displays the current author and his work's title. This
 : xhtml:span is placed in the edition's navigation bar.
 :
 :)
declare function kmgnav-utils:get-title($node as node(), $model as map(*))
as element(span)
{
  let $filename := request:get-parameter("file","")
  let $doc := doc($config:sade-data || "kmg/" || $filename || ".xml")
  
    return
          let $title-row-1 := $doc//tei:title[@type = "main"]/string()
          let $title-row-2 := $doc//tei:title[@type = "sub"]/string()

          return
            <span>
              <span style="font-weight: bolder">{$title-row-1}</span>
              <br />
              {$title-row-2}
            </span>
};